chainalysis package - Data Solutions Python SDK 0.7.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# chainalysis package

## Subpackages

- chainalysis.sql package
  - Submodules
  - chainalysis.sql.analytical module
    - `Analytical`
      - `Analytical.__call__()`
      - `Analytical.__init__()`
      - `Analytical.df()`
      - `Analytical.has_next()`
      - `Analytical.json()`
      - `Analytical.next_page()`
      - `Analytical.stats()`
      - `Analytical.status_code()`
      - `Analytical.total_pages()`
      - `Analytical.was_successful()`
  - chainalysis.sql.sql module
    - `Sql`
      - `Sql.__init__()`
  - chainalysis.sql.transactional module
    - `Transactional`
      - `Transactional.__call__()`
      - `Transactional.__init__()`
      - `Transactional.df()`
      - `Transactional.json()`
      - `Transactional.stats()`
      - `Transactional.status_code()`
      - `Transactional.was_successful()`
  - Module contents
- chainalysis.utils package
  - Submodules
  - chainalysis.utils.stringify module
    - `Stringify`
      - `Stringify.columns()`
      - `Stringify.datetimes()`
      - `Stringify.lists()`
  - chainalysis.utils.utils module
    - `Utils`
      - `Utils.__init__()`
  - Module contents

## Submodules

## chainalysis.constants module

## chainalysis.data_solutions module

class chainalysis.data_solutions.DataSolutionsClient(api_key: str)

  Bases: `object`

  This class provides SDK functions for users to query Data Solutions databases.

  The Analytical class queries the Data Solutions Analytical table. The Transactional class queries the Data Solutions Postgres table.

  __init__(api_key: str)

## Module contents